@@ -1,6 +1,6 @@
 # Copyright 2004, Ryan Kelly
-# Released under the terms of the wxWindows Licence, version 3.
-# See the file 'lincence/preamble.txt' in the main distribution for details.
+# Released under the terms of the MIT license
+# See the file 'LICENSE.txt' in the main distribution for details.
 """
 
     XRCWidgets:   GUI Toolkit build around wxPython and the XRC file format
@@ -11,11 +11,12 @@ layout is defined in such a file.
 
 """
 
-VER_MAJOR = 0
-VER_MINOR = 1
-VER_REL = 8
-VER_PATCH = ""
-VERSION = "%d.%d.%d%s" % (VER_MAJOR,VER_MINOR,VER_REL,VER_PATCH)
+__ver_major__ = 0
+__ver_minor__ = 2
+__ver_patch__  = 0
+__ver_sub__ = ""
+__version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,
+                              __ver_patch__,__ver_sub__)
 
 
 import sys
@@ -54,7 +55,7 @@ class XRCWidgetsError(Exception):
 ########
 
 class XRCWidget:
-    """Mix-in Class providing basic XRC behaviors.
+    """Mix-in class providing basic XRC behaviors.
 
     Classes inheriting from this class should also inherit from one of the
     wxPython GUI classes that can be loaded from an XRC file - for example,
@@ -96,6 +97,7 @@ class XRCWidget:
 
     def compact(self):
         """Reduce memory/resource usage of the widget.
+
         This method is called automatically after initialisation to drop
         references to unneeded resources.  These may be accumulated as
         as time goes on, so this method may be called manually to release
@@ -106,6 +108,7 @@ class XRCWidget:
 
     ##  Methods for dealing with XRC resource files
 
+    @classmethod
     def _findXRCFile(cls):
         """Locate the XRC file for this class, and return its location.
 
@@ -125,11 +128,11 @@ class XRCWidget:
             if os.path.exists(pth):
                 return pth
         raise XRCWidgetsError("XRC File '%s' could not be found" % (filePath,))
-    _findXRCFile = classmethod(_findXRCFile)
-
 
+    @staticmethod
     def _getXRCFileLocations():
         """Iterator over the possible locations where XRC files are kept.
+
         XRC files can be found in the following places:
 
             * the directories in sys.path
@@ -139,7 +142,6 @@ class XRCWidget:
         for p in sys.path:
             yield p
         yield os.path.normpath(os.path.join(sys.prefix,"share/XRCWidgets/data"))
-    _getXRCFileLocations = staticmethod(_getXRCFileLocations)
 
 
     def _loadXRCFile(self,fileNm,parent):
@@ -171,15 +173,6 @@ class XRCWidget:
             self._xmltree = XMLDocTree(xmlfile)
 
 
-    ##  wxPython 2.5 introduces the PostCreate method to wrap some
-    ##  of ugliness.  Check the wx version and implement this method
-    ##  for versions less than 2.5
-    if wx.VERSION[0] <= 2 and not wx.VERSION[1] >= 5:
-        def PostCreate(self,pre):
-            self.this = pre.this
-            self._setOORInfo(self)
-
-
     ##
     ##  Methods for obtaining references to child widgets
     ##
@@ -224,6 +217,7 @@ class XRCWidget:
 
     def getChildType(self,cName):
         """Determine the type of the named child.
+
         The type is returned as a string, typically the 'class' attribute of
         the defining element in the XRC file.  For example, "wxTextCtrl" or
         "wxListBox".
